# Rythmix.py
Rythmix.py is a simple CLI tool used to play music.

To run rythmix, simply run "rythmix" in your CMD/Terminal and it will start.
Rythmix requires VLC to run. To automatically setup VLC, simply run "sudo rythmix_setup_vlc" in your CMD/Terminal.
